[cfe-commits] r41218 - in /cfe/trunk/CodeGen: CGAggExpr.cpp CGComplexExpr.cpp

Chris Lattner sabre at nondot.org
Mon Aug 20 22:54:53 PDT 2007


Author: lattner
Date: Tue Aug 21 00:54:53 2007
New Revision: 41218

URL: http://llvm.org/viewvc/llvm-project?rev=41218&view=rev
Log:
update some comments.

Modified:
    cfe/trunk/CodeGen/CGAggExpr.cpp
    cfe/trunk/CodeGen/CGComplexExpr.cpp

Modified: cfe/trunk/CodeGen/CGAggExpr.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/CodeGen/CGAggExpr.cpp?rev=41218&r1=41217&r2=41218&view=diff

==============================================================================
--- cfe/trunk/CodeGen/CGAggExpr.cpp (original)
+++ cfe/trunk/CodeGen/CGAggExpr.cpp Tue Aug 21 00:54:53 2007
@@ -34,8 +34,6 @@
     : CGF(cgf), DestPtr(destPtr), VolatileDest(volatileDest) {
   }
 
-  typedef std::pair<llvm::Value *, llvm::Value *> ComplexPairTy;
-  
   //===--------------------------------------------------------------------===//
   //                               Utilities
   //===--------------------------------------------------------------------===//
@@ -163,6 +161,7 @@
 void CodeGenFunction::EmitAggregateCopy(llvm::Value *DestPtr,
                                         llvm::Value *SrcPtr, QualType Ty) {
   // Don't use memcpy for complex numbers.
+  // FIXME: split complex number handling out of here.
   if (Ty->isComplexType()) {
     llvm::Value *Real, *Imag;
     EmitLoadOfComplex(SrcPtr, Real, Imag);

Modified: cfe/trunk/CodeGen/CGComplexExpr.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/CodeGen/CGComplexExpr.cpp?rev=41218&r1=41217&r2=41218&view=diff

==============================================================================
--- cfe/trunk/CodeGen/CGComplexExpr.cpp (original)
+++ cfe/trunk/CodeGen/CGComplexExpr.cpp Tue Aug 21 00:54:53 2007
@@ -21,7 +21,7 @@
 using namespace CodeGen;
 
 //===----------------------------------------------------------------------===//
 //                        Aggregate Expression Emitter
 //===----------------------------------------------------------------------===//
 
 typedef std::pair<llvm::Value *, llvm::Value *> ComplexPairTy;
@@ -99,7 +99,7 @@
 //===----------------------------------------------------------------------===//
 
 ComplexPairTy ComplexExprEmitter::VisitBinaryOperator(const BinaryOperator *E) {
-  fprintf(stderr, "Unimplemented aggregate binary expr!\n");
+  fprintf(stderr, "Unimplemented complex binary expr!\n");
   E->dump();
   return ComplexPairTy();
 #if 0
@@ -269,7 +269,7 @@
   CGF.EmitBlock(LHSBlock);
   
   // Handle the GNU extension for missing LHS.
-  assert(E->getLHS() && "Must have LHS for aggregate value");
+  assert(E->getLHS() && "Must have LHS for complex value");
 
   ComplexPairTy LHS = Visit(E->getLHS());
   CGF.Builder.CreateBr(ContBlock);
@@ -21,7 +21,7 @@
 
 //===----------------------------------------------------------------------===//
-//                        Aggregate Expression Emitter
+//                        Complex Expression Emitter
 //===----------------------------------------------------------------------===//
 





More information about the cfe-commits mailing list